package Locale::CLDR::Locales::En::Any;

# This file auto generated
#	on Mon 14 Mar 12:09:30 am GMT

use version;

our $VERSION = version->declare('v0.28.4');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::En');

no Moo;

1;
